@@ -1,7 +1,7 @@
 /*
  * This file is part of the KDE Baloo Project
  * Copyright 2018  Michael Heidelbach <ottwolt@gmail.com>
- * 
+ *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
  * published by the Free Software Foundation; either version 2 of
@@ -9,12 +9,12 @@
  * accepted by the membership of KDE e.V. (or its successor approved
  * by the membership of KDE e.V.), which shall act as a proxy
  * defined in Section 14 of version 3 of the license.
- * 
+ *
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  * GNU General Public License for more details.
- * 
+ *
  * You should have received a copy of the GNU General Public License
  * along with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
@@ -36,21 +36,25 @@
 #include <KConfig>
 #include <KConfigGroup>
 
+void initLocale()
+{
+    QLocale::setDefault(QLocale("en_US"));
+}
+Q_CONSTRUCTOR_FUNCTION(initLocale)
+
 QTEST_MAIN(FileMetadataWidgetTest)
 
 void FileMetadataWidgetTest::initTestCase()
 {
     qRegisterMetaType<KFileItemList>("KFileItemList");
-    
-    qputenv("LC_ALL", "en_US.UTF-8");
-    
+
     QStandardPaths::setTestModeEnabled(true);
 
     KConfig balooConfig("baloofilerc", KConfig::NoGlobals);
     KConfigGroup balooSettings = balooConfig.group("General");
     // If we use .writePathEntry here, the test will fail.
     balooSettings.writeEntry(QStringLiteral("folders"), QString());
-    
+
     // Ensure show configuration
     KConfig config("baloofileinformationrc", KConfig::NoGlobals);
     KConfigGroup settings = config.group("Show");
@@ -64,7 +68,7 @@ void FileMetadataWidgetTest::initTestCase()
     if (exe.isEmpty()) {
         return;
     }
-    
+
     const QStringList args = {QStringLiteral("--name=user.baloo.rating"),
             QStringLiteral("--value=5") ,
             QFINDTESTDATA("samplefiles/testtagged.mp3"),
@@ -113,19 +117,19 @@ void FileMetadataWidgetTest::shouldSignalOnceWithEmptyFile()
 void FileMetadataWidgetTest::shouldSignalOnceFile()
 {
     QSignalSpy spy(m_widget, &Baloo::FileMetaDataWidget::metaDataRequestFinished);
-    m_widget->setItems(KFileItemList() 
+    m_widget->setItems(KFileItemList()
         << QUrl::fromLocalFile(QFINDTESTDATA("samplefiles/testtagged.m4a"))
     );
     QVERIFY(spy.wait());
     QCOMPARE(spy.count(), 1);
     QCOMPARE(m_widget->items().count(), 1);
-    
+
 }
 
 void FileMetadataWidgetTest::shouldSignalOnceFiles()
 {
     QSignalSpy spy(m_widget, &Baloo::FileMetaDataWidget::metaDataRequestFinished);
-    m_widget->setItems(KFileItemList() 
+    m_widget->setItems(KFileItemList()
         << QUrl::fromLocalFile(QFINDTESTDATA("samplefiles/test.mp3"))
         << QUrl::fromLocalFile(QFINDTESTDATA("samplefiles/testtagged.mp3"))
         << QUrl::fromLocalFile(QFINDTESTDATA("samplefiles/testtagged.m4a"))
@@ -138,18 +142,18 @@ void FileMetadataWidgetTest::shouldSignalOnceFiles()
 void FileMetadataWidgetTest::shouldShowProperties()
 {
     QSignalSpy spy(m_widget, &Baloo::FileMetaDataWidget::metaDataRequestFinished);
-    m_widget->setItems(KFileItemList() 
+    m_widget->setItems(KFileItemList()
         << QUrl::fromLocalFile(QFINDTESTDATA("samplefiles/testtagged.mp3"))
     );
-    
+
     QVERIFY(spy.wait());
     QCOMPARE(spy.count(), 1);
-    
+
     // simple property
     QLabel* valueWidget = m_widget->findChild<QLabel*>("kfileitem#type");
     QVERIFY2(valueWidget, "Type data missing");
     QCOMPARE(valueWidget->text(), QLatin1String("MP3 audio"));
-    
+
     if (m_mayTestRating) {
         // editable property
         KRatingWidget* ratingWidget = m_widget->findChild<KRatingWidget*>("rating");
@@ -162,27 +166,27 @@ void FileMetadataWidgetTest::shouldShowProperties()
     valueWidget = m_widget->findChild<QLabel*>("albumArtist");
     QVERIFY2(valueWidget, "albumArtist data was not found");
     QCOMPARE(valueWidget->text(), QLatin1String("Bill Laswell"));
-    
+
 }
 
 void FileMetadataWidgetTest::shouldShowCommonProperties()
 {
     QSignalSpy spy(m_widget, &Baloo::FileMetaDataWidget::metaDataRequestFinished);
-    m_widget->setItems(KFileItemList() 
+    m_widget->setItems(KFileItemList()
         << QUrl::fromLocalFile(QFINDTESTDATA("samplefiles/testtagged.mp3"))
         << QUrl::fromLocalFile(QFINDTESTDATA("samplefiles/testtagged.m4a"))
     );
     QVERIFY(spy.wait());
     QCOMPARE(spy.count(), 1);
-    
+
     // simple property
     QLabel* valueWidget = m_widget->findChild<QLabel*>("kfileitem#type");
     QVERIFY(!valueWidget);
-    
+
     valueWidget = m_widget->findChild<QLabel*>("kfileitem#totalSize");
     // circumvent i18n formatting
     QCOMPARE(valueWidget->text().left(3), QLatin1String("153"));
-    
+
     // editable property
     if (m_mayTestRating) {
         KRatingWidget* ratingWidget = m_widget->findChild<KRatingWidget*>("rating");
